Scheduler
=========

.. currentmodule:: atqo

.. autoclass:: Scheduler
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Scheduler.is_empty
      ~Scheduler.is_idle
      ~Scheduler.queued_task_count

   .. rubric:: Methods Summary

   .. autosummary::

      ~Scheduler.get_processed_results
      ~Scheduler.join
      ~Scheduler.process
      ~Scheduler.refill_task_queue
      ~Scheduler.wait_until_n_tasks_remain

   .. rubric:: Attributes Documentation

   .. autoattribute:: is_empty
   .. autoattribute:: is_idle
   .. autoattribute:: queued_task_count

   .. rubric:: Methods Documentation

   .. automethod:: get_processed_results
   .. automethod:: join
   .. automethod:: process
   .. automethod:: refill_task_queue
   .. automethod:: wait_until_n_tasks_remain
